@@ -9,6 +9,8 @@ from .. import gitcmds
 from .. import gitcfg
 from .. import version
 from ..git import STDOUT
+from ..interaction import Interaction
+from ..i18n import N_
 from . import prefs
 
 
@@ -27,7 +29,7 @@ class MainModel(QtCore.QObject):
     """Repository status model"""
 
     # Refactor: split this class apart into separate DiffModel, CommitMessageModel,
-    # StatusModel, and an DiffEditorState.
+    # StatusModel, and a DiffEditorState.
 
     # Signals
     about_to_update = Signal()
@@ -362,7 +364,7 @@ class MainModel(QtCore.QObject):
         return not self.local_branches
 
     def _update_remotes(self):
-        self.remotes = gitcfg.get_remotes(self.cfg)
+        self.remotes = sorted(gitcfg.get_remotes(self.cfg))
 
     def _update_branches_and_tags(self):
         context = self.context
@@ -449,12 +451,7 @@ class MainModel(QtCore.QObject):
         self.update_refs()
         return result
 
-    def push(self, remote, remote_branch='', local_branch='', **opts):
-        # Swap the branches in push mode (reverse of fetch)
-        opts.update({
-            'local_branch': remote_branch,
-            'remote_branch': local_branch,
-        })
+    def push(self, remote, **opts):
         result = run_remote_action(self.context, self.git.push, remote, PUSH, **opts)
         self.update_refs()
         return result
@@ -589,5 +586,147 @@ def refspec_arg(local_branch, remote_branch, remote, action):
 
 def run_remote_action(context, fn, remote, action, **kwargs):
     """Run fetch, push or pull"""
+    kwargs.pop('_add_env', None)
     args, kwargs = remote_args(context, remote, action, **kwargs)
+    autodetect_proxy(context, kwargs)
+    no_color(kwargs)
     return fn(*args, **kwargs)
+
+
+def no_color(kwargs):
+    """Augment kwargs with an _add_env environment dict that disables colors"""
+    try:
+        env = kwargs['_add_env']
+    except KeyError:
+        env = kwargs['_add_env'] = {}
+    else:
+        if env is None:
+            env = kwargs['_add_env'] = {}
+    env['NO_COLOR'] = '1'
+    env['TERM'] = 'dumb'
+
+
+def autodetect_proxy(context, kwargs):
+    """Detect proxy settings when running on Gnome and KDE"""
+    # kwargs can refer to persistent global state so we purge it.
+    # Callers should not expect their _add_env to persist.
+    kwargs.pop('_add_env', None)
+    enabled = prefs.autodetect_proxy(context)
+    if not enabled:
+        return
+    # If "git config http.proxy" is configured then there's nothing to do.
+    http_proxy = prefs.http_proxy(context)
+    if http_proxy:
+        Interaction.log(
+            N_('http proxy configured by "git config http.proxy %(url)s"')
+            % dict(url=http_proxy)
+        )
+        return
+    # This function has the side-effect of updating the kwargs dict.
+    # The "_add_env" parameter gets forwarded to the __getattr__ git function's
+    # _add_env option which forwards to core.run_command()'s add_env option.
+    add_env = autodetect_proxy_environ()
+    if add_env:
+        kwargs['_add_env'] = add_env
+
+
+def autodetect_proxy_environ():
+    """Return the environment variables used for configuring proxies"""
+    add_env = {}
+    xdg_current_desktop = core.getenv('XDG_CURRENT_DESKTOP', default='')
+    if not xdg_current_desktop:
+        return add_env
+
+    http_proxy = None
+    https_proxy = None
+    if xdg_current_desktop == 'KDE' or xdg_current_desktop.endswith(':KDE'):
+        kreadconfig = core.find_executable('kreadconfig5')
+        if kreadconfig:
+            http_proxy = autodetect_proxy_kde(kreadconfig, 'http')
+            https_proxy = autodetect_proxy_kde(kreadconfig, 'https')
+    elif xdg_current_desktop:
+        # If we're not on KDE then we'll fallback to GNOME / gsettings.
+        gsettings = core.find_executable('gsettings')
+        if gsettings and autodetect_proxy_gnome_is_enabled(gsettings):
+            http_proxy = autodetect_proxy_gnome(gsettings, 'http')
+            https_proxy = autodetect_proxy_gnome(gsettings, 'https')
+
+    if os.environ.get('http_proxy'):
+        Interaction.log(
+            N_('http proxy configured by the "http_proxy" environment variable')
+        )
+    elif http_proxy:
+        Interaction.log(
+            N_('%(scheme)s proxy configured from %(desktop)s settings: %(url)s')
+            % dict(scheme='http', desktop=xdg_current_desktop, url=http_proxy)
+        )
+        add_env['http_proxy'] = http_proxy
+
+    if os.environ.get('https_proxy', None):
+        Interaction.log(
+            N_('https proxy configured by the "https_proxy" environment variable')
+        )
+    elif https_proxy:
+        Interaction.log(
+            N_('%(scheme)s proxy configured from %(desktop)s settings: %(url)s')
+            % dict(scheme='https', desktop=xdg_current_desktop, url=https_proxy)
+        )
+        add_env['https_proxy'] = https_proxy
+
+    return add_env
+
+
+def autodetect_proxy_gnome_is_enabled(gsettings):
+    """Is the proxy manually configured on Gnome?"""
+    status, out, _ = core.run_command(
+        [gsettings, 'get', 'org.gnome.system.proxy', 'mode']
+    )
+    return status == 0 and out.strip().strip("'") == 'manual'
+
+
+def autodetect_proxy_gnome(gsettings, scheme):
+    """Return the configured HTTP proxy for Gnome"""
+    status, out, _ = core.run_command(
+        [gsettings, 'get', f'org.gnome.system.proxy.{scheme}', 'host']
+    )
+    if status != 0:
+        return None
+    host = out.strip().strip("'")
+    port = ''
+    status, out, _ = core.run_command(
+        [gsettings, 'get', f'org.gnome.system.proxy.{scheme}', 'port']
+    )
+    if status == 0:
+        port = ':' + out.strip()
+    proxy = host + port
+    return proxy
+
+
+def autodetect_proxy_kde(kreadconfig, scheme):
+    """Return the configured HTTP proxy for KDE"""
+    cmd = [
+        kreadconfig,
+        '--file',
+        'kioslaverc',
+        '--group',
+        'Proxy Settings',
+        '--key',
+        'ProxyType',
+    ]
+    status, out, err = core.run_command(cmd)
+    if status == 0 and out.strip() == '1':
+        cmd = [
+            kreadconfig,
+            '--file',
+            'kioslaverc',
+            '--group',
+            'Proxy Settings',
+            '--key',
+            f'{scheme}Proxy',
+        ]
+        status, out, err = core.run_command(cmd)
+        if status == 0:
+            proxy = out.strip().replace(' ', ':')
+            return proxy
+        return None
+    return None
