@@ -52,9 +52,7 @@ def connect_button(button, func):
 
 def connect_checkbox(widget, func):
     """Connect a checkbox to a function taking bool"""
-    widget.clicked.connect(
-        lambda *args, **kwargs: func(get(checkbox)), type=Qt.QueuedConnection
-    )
+    widget.clicked.connect(lambda value: func(value), type=Qt.QueuedConnection)
 
 
 def connect_released(button, func):
@@ -239,14 +237,22 @@ class ComboBox(QtWidgets.QComboBox):
         idx = utils.clamp(idx, 0, self.count() - 1)
         self.setCurrentIndex(idx)
 
-    def add_item(self, text, data):
+    def add_item(self, text, data=None):
+        if data is None:
+            data = text
         self.addItem(text)
         self.item_data.append(data)
 
-    def current_data(self):
+    def value(self):
+        """Return the current data"""
         return self.item_data[self.currentIndex()]
 
+    def values(self):
+        """Return all of the valid values"""
+        return self.item_data
+
     def set_value(self, value):
+        """Set the value to one of the known values"""
         if self.transform:
             value = self.transform(value)
         try:
@@ -255,6 +261,14 @@ class ComboBox(QtWidgets.QComboBox):
             index = 0
         self.setCurrentIndex(index)
 
+    def set_current_value(self, value):
+        """Set the current value irrespective of the preset values"""
+        self.setCurrentText(value)
+
+    def current_value(self):
+        """Return the current value irrespective of the preset values"""
+        return self.currentText()
+
 
 def combo(items, editable=False, tooltip='', parent=None):
     """Create a readonly (by default) combo box from a list of items"""
@@ -268,7 +282,7 @@ def combo_mapped(data, editable=False, transform=None, parent=None):
     """Create a readonly (by default) combo box from a list of items"""
     widget = ComboBox(editable=editable, transform=transform, parent=parent)
     for k, v in data:
-        widget.add_item(k, v)
+        widget.add_item(k, data=v)
     return widget
 
 
@@ -822,14 +836,18 @@ def _checkbox(cls, text, tooltip, checked):
 
 
 class DockTitleBarWidget(QtWidgets.QFrame):
-    def __init__(self, parent, title, stretch=True):
+    """Provides a dockwidget titlebar that can be extended with custom widgets"""
+
+    def __init__(self, parent, title, stretch=True, hide_title=False):
         QtWidgets.QFrame.__init__(self, parent)
         self.setAutoFillBackground(True)
-        self.label = qlabel = QtWidgets.QLabel(title, self)
-        qfont = qlabel.font()
-        qfont.setBold(True)
-        qlabel.setFont(qfont)
-        qlabel.setCursor(Qt.OpenHandCursor)
+        self.label = QtWidgets.QLabel(title, self)
+        self.label.setCursor(Qt.OpenHandCursor)
+        font = self.label.font()
+        font.setPointSize(defs.action_text)
+        self.label.setFont(font)
+        if hide_title:
+            self.label.hide()
 
         self.close_button = create_action_button(
             tooltip=N_('Close'), icon=icons.close()
@@ -838,9 +856,10 @@ class DockTitleBarWidget(QtWidgets.QFrame):
         self.toggle_button = create_action_button(
             tooltip=N_('Detach'), icon=icons.external()
         )
+        self.toggle_button.hide()
 
         self.corner_layout = hbox(defs.no_margin, defs.spacing)
-        self.title_layout = hbox(defs.no_margin, defs.button_spacing, qlabel)
+        self.title_layout = hbox(defs.no_margin, defs.button_spacing, self.label)
 
         if stretch:
             separator = STRETCH
@@ -856,19 +875,23 @@ class DockTitleBarWidget(QtWidgets.QFrame):
             self.toggle_button,
             self.close_button,
         )
+        self.main_layout.setAlignment(self.toggle_button, Qt.AlignTop)
+        self.main_layout.setAlignment(self.close_button, Qt.AlignTop)
         self.setLayout(self.main_layout)
 
         connect_button(self.toggle_button, self.toggle_floating)
         connect_button(self.close_button, self.toggle_visibility)
 
     def toggle_floating(self):
+        """Toggle between floating and embedded modes"""
         self.parent().setFloating(not self.parent().isFloating())
-        self.update_tooltips()
 
     def toggle_visibility(self):
+        """Toggle visibility of the dock widget"""
         self.parent().toggleViewAction().trigger()
 
     def set_title(self, title):
+        """Set the title text"""
         self.label.setText(title)
 
     def add_title_widget(self, widget):
@@ -879,22 +902,31 @@ class DockTitleBarWidget(QtWidgets.QFrame):
         """Add widgets to the corner area"""
         self.corner_layout.addWidget(widget)
 
-    def update_tooltips(self):
-        if self.parent().isFloating():
+    def update_floating(self):
+        """Refresh the floating state"""
+        self.set_floating(self.parent().isFloating())
+
+    def set_floating(self, floating):
+        """Update state in response to floating state changes"""
+        if floating:
             tooltip = N_('Attach')
         else:
             tooltip = N_('Detach')
         self.toggle_button.setToolTip(tooltip)
+        self.toggle_button.setVisible(floating)
 
 
-def create_dock(name, title, parent, stretch=True, widget=None, func=None):
+def create_dock(
+    name, title, parent, stretch=True, widget=None, func=None, hide_title=False
+):
     """Create a dock widget and set it up accordingly."""
     dock = QtWidgets.QDockWidget(parent)
     dock.setWindowTitle(title)
     dock.setObjectName(name)
-    titlebar = DockTitleBarWidget(dock, title, stretch=stretch)
+    titlebar = DockTitleBarWidget(dock, title, stretch=stretch, hide_title=hide_title)
     dock.setTitleBarWidget(titlebar)
     dock.setAutoFillBackground(True)
+    dock.topLevelChanged.connect(titlebar.set_floating)
     if hasattr(parent, 'dockwidgets'):
         parent.dockwidgets.append(dock)
     if func:
@@ -948,7 +980,7 @@ def add_menu(title, parent):
     return menu
 
 
-def create_toolbutton(text=None, layout=None, tooltip=None, icon=None):
+def create_toolbutton(text=None, layout=None, tooltip=None, icon=None, repeat=False):
     button = tool_button()
     if icon is not None:
         button.setIcon(icon)
@@ -958,14 +990,20 @@ def create_toolbutton(text=None, layout=None, tooltip=None, icon=None):
         button.setToolButtonStyle(Qt.ToolButtonTextBesideIcon)
     if tooltip is not None:
         button.setToolTip(tooltip)
+    if repeat:
+        button.setAutoRepeat(True)
     if layout is not None:
         layout.addWidget(button)
     return button
 
 
-def create_toolbutton_with_callback(callback, text, icon, tooltip, layout=None):
+def create_toolbutton_with_callback(
+    callback, text, icon, tooltip, layout=None, repeat=False
+):
     """Create a tool button that runs the specified callback"""
-    toolbutton = create_toolbutton(text=text, layout=layout, tooltip=tooltip, icon=icon)
+    toolbutton = create_toolbutton(
+        text=text, layout=layout, tooltip=tooltip, icon=icon, repeat=repeat
+    )
     connect_button(toolbutton, callback)
     return toolbutton
 
@@ -1190,7 +1228,7 @@ def css_color(value):
 
 
 def hsl(hue, saturation, lightness):
-    """Return a QColor from an hue, saturation and lightness"""
+    """Return a QColor from hue, saturation and lightness"""
     return QtGui.QColor.fromHslF(
         utils.clamp(hue, 0.0, 1.0),
         utils.clamp(saturation, 0.0, 1.0),
