@@ -135,7 +135,14 @@ class WidgetMixin:
             width = defs.dialog_w
         if not height:
             height = defs.dialog_h
-        self.init_state(settings, self.resize_to_parent, parent, width, height)
+        self.init_state(
+            settings,
+            self.resize_to_parent,
+            parent,
+            width,
+            height,
+            use_parent_height=True,
+        )
 
     def init_state(self, settings, callback, *args, **kwargs):
         """Restore saved settings or set the initial location"""
@@ -143,9 +150,11 @@ class WidgetMixin:
             callback(*args, **kwargs)
             self.center()
 
-    def resize_to_parent(self, parent, w, h):
+    def resize_to_parent(self, parent, w, h, use_parent_height=True):
         """Set the initial size of the widget"""
-        width, height = qtutils.default_size(parent, w, h)
+        width, height = qtutils.default_size(
+            parent, w, h, use_parent_height=use_parent_height
+        )
         self.resize(width, height)
 
 
@@ -164,6 +173,14 @@ class MainWindowMixin(WidgetMixin):
         self.default_state = self.saveState(self.widget_version)
         super().init_state(settings, callback, *args, **kwargs)
 
+    def layout_state(self):
+        """Return the Qt layout state"""
+        return self.saveState(self.widget_version)
+
+    def apply_layout(self, value):
+        """Apply binary Qt layout state"""
+        self.restoreState(value, self.widget_version)
+
     def export_state(self):
         """Exports data for save/restore"""
         state = WidgetMixin.export_state(self)
@@ -180,7 +197,12 @@ class MainWindowMixin(WidgetMixin):
             else:
                 settings = context.settings
                 settings.load()
-            settings.add_recent(core.getcwd(), prefs.maxrecent(context))
+            try:
+                cwd = core.getcwd()
+            except FileNotFoundError:
+                pass
+            else:
+                settings.add_recent(cwd, prefs.maxrecent(context))
         return WidgetMixin.save_settings(self, settings=settings)
 
     def apply_state(self, state):
@@ -199,7 +221,7 @@ class MainWindowMixin(WidgetMixin):
 
         self.lock_layout = state.get('lock_layout', self.lock_layout)
         self.update_dockwidget_lock_state()
-        self.update_dockwidget_tooltips()
+        self.update_dockwidget_floating_state()
 
         return result
 
@@ -220,12 +242,13 @@ class MainWindowMixin(WidgetMixin):
                 | QDockWidget.DockWidgetMovable
             )
         for widget in self.dockwidgets:
-            widget.titleBarWidget().update_tooltips()
             widget.setFeatures(features)
+            widget.titleBarWidget().update_floating()
 
-    def update_dockwidget_tooltips(self):
+    def update_dockwidget_floating_state(self):
+        """Update the floating state for all dock widgets"""
         for widget in self.dockwidgets:
-            widget.titleBarWidget().update_tooltips()
+            widget.titleBarWidget().update_floating()
 
 
 class ListWidget(QtWidgets.QListWidget):
