@@ -1,6 +1,4 @@
 """Provides quick switcher"""
-import re
-
 from qtpy import QtCore
 from qtpy import QtGui
 from qtpy.QtCore import Qt
@@ -81,9 +79,14 @@ class Switcher(standard.Dialog):
         self.filter_input.textChanged.connect(self.filter_input_changed)
 
     def filter_input_changed(self):
+        """Update the proxy model filter when the input text changes"""
         input_text = self.filter_input.text()
-        pattern = '.*'.join(re.escape(c) for c in input_text)
-        self.proxy_model.setFilterRegExp(pattern)
+        # Use a case-sensitive search when the input text is ALL_CAPS or mixedCaps.
+        if input_text.upper() == input_text or input_text.lower() != input_text:
+            self.proxy_model.setFilterCaseSensitivity(Qt.CaseSensitive)
+        else:
+            self.proxy_model.setFilterCaseSensitivity(Qt.CaseInsensitive)
+        self.proxy_model.setFilterWildcard(input_text)
 
 
 class SwitcherInnerView(Switcher):
@@ -165,13 +168,12 @@ class SwitcherOuterView(Switcher):
             parent=parent,
         )
         self.filter_input.hide()
-
         self.main_layout = qtutils.vbox(defs.no_margin, defs.spacing, self.filter_input)
         self.setLayout(self.main_layout)
+        self.filter_input.editingFinished.connect(self.filter_input_edited)
 
-    def filter_input_changed(self):
-        super().filter_input_changed()
-        # Hide the input when it becomes empty.
+    def filter_input_edited(self):
+        """Hide the filter input when editing is complete and the text is empty"""
         input_text = self.filter_input.text()
         if not input_text:
             self.filter_input.hide()
@@ -230,7 +232,6 @@ class SwitcherSortFilterProxyModel(QtCore.QSortFilterProxyModel):
         return self.entries.itemFromIndex(self.mapToSource(index))
 
 
-# pylint: disable=too-many-ancestors
 class SwitcherTreeView(standard.TreeView):
     """Tree view class for showing proxy items in SwitcherSortFilterProxyModel"""
 
