@@ -319,19 +319,18 @@ def restore_session(args):
         args.repo = session.repo
 
 
-def application_init(args, update=False):
+def application_init(args, update=False, app_name='Git Cola'):
     """Parses the command-line arguments and starts git-cola"""
     # Ensure that we're working in a valid git repository.
     # If not, try to find one.  When found, chdir there.
     setup_environment()
     process_args(args)
 
-    context = new_context(args)
+    context = new_context(args, app_name=app_name)
     timer = context.timer
     timer.start('init')
 
     new_worktree(context, args.repo, args.prompt)
-
     if update:
         context.model.update_status()
 
@@ -341,7 +340,7 @@ def application_init(args, update=False):
     return context
 
 
-def new_context(args):
+def new_context(args, app_name='Git Cola'):
     """Create top-level ApplicationContext objects"""
     context = ApplicationContext(args)
     context.settings = args.settings or Settings.read()
@@ -350,12 +349,19 @@ def new_context(args):
     context.fsmonitor = fsmonitor.create(context)
     context.selection = selection.create()
     context.model = main.create(context)
+    context.app_name = app_name
     context.app = new_application(context, args)
     context.timer = Timer()
 
     return context
 
 
+def create_context():
+    """Create a one-off context from the current directory"""
+    args = null_args()
+    return new_context(args)
+
+
 def application_run(context, view, start=None, stop=None):
     """Run the application main loop"""
     initialize_view(context, view)
@@ -440,7 +446,7 @@ def add_common_arguments(parser):
 
     # Specify the GUI theme
     parser.add_argument(
-        '--theme', metavar='<name>', default=None, help='specify an GUI theme name'
+        '--theme', metavar='<name>', default=None, help='specify a GUI theme name'
     )
 
 
@@ -509,7 +515,8 @@ def async_update(context):
 
     git-cola should startup as quickly as possible.
     """
-    update_status = partial(context.model.update_status, update_index=True)
+    update_index = context.cfg.get('cola.updateindex', True)
+    update_status = partial(context.model.update_status, update_index=update_index)
     task = qtutils.SimpleTask(update_status)
     context.runtask.start(task)
 
