@@ -1,8 +1,7 @@
 """Base Command class"""
-from __future__ import absolute_import, division, print_function, unicode_literals
 
 
-class Command(object):
+class Command:
     """Mixin interface for commands"""
 
     UNDOABLE = False
