@@ -799,7 +799,9 @@ class UndoLastCommit(ResetCommand):
 class Commit(ResetMode):
     """Attempt to create a new commit."""
 
-    def __init__(self, context, amend, msg, sign, no_verify=False):
+    def __init__(
+        self, context, amend, msg, sign, no_verify=False, author=None, date=None
+    ):
         super().__init__(context)
         self.amend = amend
         self.msg = msg
@@ -807,21 +809,39 @@ class Commit(ResetMode):
         self.no_verify = no_verify
         self.old_commitmsg = self.model.commitmsg
         self.new_commitmsg = ''
+        self.author = author
+        self.date = date
 
     def do(self):
         # Create the commit message file
         context = self.context
         msg = self.msg
         tmp_file = utils.tmp_filename('commit-message')
+        add_env = {
+            'NO_COLOR': '1',
+            'TERM': 'dumb',
+        }
+        add_env.update(main.autodetect_proxy_environ())
+        kwargs = {}
+        # Override the commit date.
+        if self.date:
+            add_env['GIT_AUTHOR_DATE'] = self.date
+            add_env['GIT_COMMITTER_DATE'] = self.date
+            kwargs['date'] = self.date
+        # Override the commit author.
+        if self.author:
+            kwargs['author'] = self.author
         try:
             core.write(tmp_file, msg)
             # Run 'git commit'
             status, out, err = self.git.commit(
+                _add_env=add_env,
                 F=tmp_file,
                 v=True,
                 gpg_sign=self.sign,
                 amend=self.amend,
                 no_verify=self.no_verify,
+                **kwargs,
             )
         finally:
             core.unlink(tmp_file)
@@ -1187,7 +1207,10 @@ class DeleteRemoteBranch(DeleteBranch):
         self.remote = remote
 
     def action(self):
-        return self.git.push(self.remote, self.branch, delete=True)
+        kwargs = {}
+        main.autodetect_proxy(self.context, kwargs)
+        main.no_color(kwargs)
+        return self.git.push(self.remote, self.branch, delete=True, **kwargs)
 
     def success(self):
         self.model.update_status()
@@ -1526,9 +1549,19 @@ class Edit(ContextCommand):
     def name():
         return N_('Launch Editor')
 
-    def __init__(self, context, filenames, line_number=None, background_editor=False):
+    def __init__(
+        self,
+        context,
+        filenames,
+        selected_filename=None,
+        line_number=None,
+        background_editor=False,
+    ):
         super().__init__(context)
+        if filenames and not selected_filename:
+            selected_filename = filenames[0]
         self.filenames = filenames
+        self.selected_filename = selected_filename
         self.line_number = line_number
         self.background_editor = background_editor
 
@@ -1536,38 +1569,43 @@ class Edit(ContextCommand):
         context = self.context
         if not self.filenames:
             return
-        filename = self.filenames[0]
-        if not core.exists(filename):
-            return
+
         if self.background_editor:
             editor = prefs.background_editor(context)
         else:
             editor = prefs.editor(context)
-        opts = []
-
-        if self.line_number is None:
-            opts = self.filenames
+        if self.line_number is None or self.selected_filename is None:
+            args = self.filenames
         else:
-            # Single-file w/ line-numbers (likely from grep)
+            args = []
+            # grep and diff are able to open files at specific line numbers.
+            # We only know the line number for the first file.
+            # Some editors can only apply the '+<line-number>' argument to one file.
+            filename = self.selected_filename
             editor_opts = {
-                '*vim*': [filename, '+%s' % self.line_number],
+                '*vim*': ['+%s' % self.line_number, filename],
                 '*emacs*': ['+%s' % self.line_number, filename],
                 '*textpad*': [f'{filename}({self.line_number},0)'],
                 '*notepad++*': ['-n%s' % self.line_number, filename],
                 '*subl*': [f'{filename}:{self.line_number}'],
             }
 
-            opts = self.filenames
-            for pattern, opt in editor_opts.items():
+            use_line_numbers = False
+            for pattern, opts in editor_opts.items():
                 if fnmatch(editor, pattern):
-                    opts = opt
+                    args.extend(opts)
+                    use_line_numbers = True
                     break
+            if use_line_numbers:
+                args.extend(fname for fname in self.filenames if fname != filename)
+            else:
+                args = self.filenames
 
         try:
-            core.fork(utils.shell_split(editor) + opts)
-        except (OSError, ValueError) as e:
+            core.fork(utils.shell_split(editor) + args)
+        except (OSError, ValueError) as err:
             message = N_('Cannot exec "%s": please configure your editor') % editor
-            _, details = utils.format_exception(e)
+            _, details = utils.format_exception(err)
             Interaction.critical(N_('Error Editing File'), message, details)
 
 
@@ -1640,6 +1678,11 @@ class LaunchEditorAtLine(LaunchEditor):
     def __init__(self, context):
         super().__init__(context)
         self.line_number = context.selection.line_number
+        # Ensure that the model's filename is present in self.filenames otherwise we
+        # will open a file that the user never requested. This constraint also ensures
+        # that the line number corresponds to the selected filename.
+        if context.model.filename in self.filenames:
+            self.selected_filename = context.model.filename
 
 
 class LoadCommitMessageFromFile(ContextCommand):
@@ -2028,8 +2071,13 @@ class Rebase(ContextCommand):
         kwargs.update(self.kwargs)
 
         # Prompt to determine whether or not to use "git rebase --update-refs".
+        update_refs = self.context.cfg.get(prefs.REBASE_UPDATE_REFS)
         has_update_refs = version.check_git(self.context, 'rebase-update-refs')
-        if has_update_refs and not kwargs.get('update_refs', False):
+        if (
+            has_update_refs
+            and update_refs is None
+            and not kwargs.get('update_refs', False)
+        ):
             title = N_('Update stacked branches when rebasing?')
             text = N_(
                 '"git rebase --update-refs" automatically force-updates any\n'
