@@ -27,8 +27,8 @@ from .. import qtutils
 from .text import TextDecorator
 from .text import VimHintedPlainTextEdit
 from .text import PlainTextLabel
-from .text import RichTextLabel
 from .text import TextSearchWidget
+from .text import label_selection_timer
 from . import defs
 from . import standard
 from . import imageview
@@ -185,7 +185,6 @@ class DiffSyntaxHighlighter(QtGui.QSyntaxHighlighter):
         return state, formats
 
 
-# pylint: disable=too-many-ancestors
 class DiffTextEdit(VimHintedPlainTextEdit):
     """A textedit for interacting with diff text"""
 
@@ -197,33 +196,44 @@ class DiffTextEdit(VimHintedPlainTextEdit):
         self.highlighter = DiffSyntaxHighlighter(
             context, self.document(), is_commit=is_commit, whitespace=whitespace
         )
+        self.diff_lines = diffparse.DiffLines()
         if numbers:
-            self.numbers = DiffLineNumbers(context, self)
+            self.numbers = DiffLineNumbers(context, self, diff_lines=self.diff_lines)
             self.numbers.hide()
         else:
             self.numbers = None
         self.scrollvalue = None
 
-        self.copy_diff_action = qtutils.add_action(
+        self.copy_diff_action = qtutils.add_action_with_icon(
             self,
+            icons.copy(),
             N_('Copy Diff'),
             self.copy_diff,
             hotkeys.COPY_DIFF,
         )
-        self.copy_diff_action.setIcon(icons.copy())
         self.copy_diff_action.setEnabled(False)
         self.menu_actions.append(self.copy_diff_action)
-
-        # pylint: disable=no-member
         self.cursorPositionChanged.connect(self._cursor_changed)
         self.selectionChanged.connect(self._selection_changed)
+        self.mouse_zoomed.connect(self.update_block_cursor)
 
     def setFont(self, font):
         """Override setFont() so that we can use a custom "block" cursor"""
         super().setFont(font)
-        if prefs.block_cursor(self.context):
-            width = qtutils.text_width(font, 'M')
-            self.setCursorWidth(width)
+        self.update_block_cursor(font=font)
+
+    def update_block_cursor(self, font=None):
+        """Update the block cusor width"""
+        self._update_block_cursor(self.context, font=font)
+
+    def _update_block_cursor(self, context, font=None):
+        """Update the block cusor width"""
+        if not prefs.block_cursor(context):
+            return
+        if font is None:
+            font = self.font()
+        width = qtutils.text_width(font, 'M')
+        self.setCursorWidth(width)
 
     def _cursor_changed(self):
         """Update the line number display when the cursor changes"""
@@ -269,11 +279,13 @@ class DiffTextEdit(VimHintedPlainTextEdit):
         diff = diff.rstrip('\n')  # diffs include two empty newlines
         self.save_scrollbar()
 
-        self.hint.set_value('')
+        lines = self.diff_lines.parse(diff)
         if self.numbers:
-            self.numbers.set_diff(diff)
-        self.set_value(diff)
+            # The diff_lines parser is shared with self.numbers and updated above.
+            self.numbers.set_diff(diff, lines=lines)
 
+        self.hint.set_value('')
+        self.set_value(diff)
         self.restore_scrollbar()
 
     def selected_diff_stripped(self):
@@ -343,11 +355,13 @@ def _strip_diff(value):
 
 
 class DiffLineNumbers(TextDecorator):
-    def __init__(self, context, parent):
+    """The diff viewer's line number display"""
+
+    def __init__(self, context, parent, diff_lines=None):
         TextDecorator.__init__(self, parent)
         self.highlight_line = -1
         self.lines = None
-        self.parser = diffparse.DiffLines()
+        self.parser = diff_lines or diffparse.DiffLines()
         self.formatter = diffparse.FormatDigits()
 
         font = qtutils.diff_font(context)
@@ -363,8 +377,11 @@ class DiffLineNumbers(TextDecorator):
         self._window = palette.color(QPalette.Window)
         self._disabled = palette.color(QPalette.Disabled, QPalette.Text)
 
-    def set_diff(self, diff):
-        self.lines = self.parser.parse(diff)
+    def set_diff(self, diff, lines=None):
+        """Update to a new diff display"""
+        if lines is None:
+            lines = self.parser.parse(diff)
+        self.lines = lines
         self.formatter.set_digits(self.parser.digits())
 
     def width_hint(self):
@@ -480,15 +497,24 @@ class Viewer(QtWidgets.QFrame):
         self.images = []
         self.pixmaps = []
         self.options = options = Options(self)
+        italic_font = self.font()
+        italic_font.setItalic(True)
+
         self.filename = PlainTextLabel(parent=self)
         self.filename.setAlignment(Qt.AlignVCenter | Qt.AlignLeft)
-        font = self.font()
-        font.setItalic(True)
-        self.filename.setFont(font)
+        self.filename.setFont(italic_font)
         self.filename.elide()
+
+        diffstat_font = self.font()
+        diffstat_font.setPointSize(diffstat_font.pointSize() - 1)
+        self.diffstat = PlainTextLabel(parent=self)
+        self.diffstat.setAlignment(Qt.AlignVCenter | Qt.AlignRight)
+        self.diffstat.setFont(diffstat_font)
+
         self.text = DiffEditor(context, options, self)
         self.image = imageview.ImageView(parent=self)
         self.image.setFocusPolicy(Qt.NoFocus)
+
         self.search_widget = TextSearchWidget(self.text, self)
         self.search_widget.hide()
         self._drag_has_patches = False
@@ -517,6 +543,9 @@ class Viewer(QtWidgets.QFrame):
         # Observe the file type
         model.file_type_changed.connect(self.set_file_type, type=Qt.QueuedConnection)
 
+        # Observe the diff text
+        model.diff_text_updated.connect(self.set_diff, type=Qt.QueuedConnection)
+
         # Observe the image mode combo box
         options.image_mode.currentIndexChanged.connect(lambda _: self.render())
         options.zoom_mode.currentIndexChanged.connect(lambda _: self.render())
@@ -594,6 +623,17 @@ class Viewer(QtWidgets.QFrame):
         self.set_word_wrapping(word_wrap, update=True)
         return True
 
+    def set_diff(self, diff):
+        """Update the diffstat display in reponse to the new diff"""
+        filename = self.context.selection.filename()
+        if filename:
+            removals = self.text.diff_lines.removals.count
+            additions = self.text.diff_lines.additions.count
+            diffstat = f'-{removals}  +{additions}'
+        else:
+            diffstat = ''
+        self.diffstat.set_text(diffstat)
+
     def set_diff_type(self, diff_type):
         """Manage the image and text diff views when selection changes"""
         # The "diff type" is whether the diff viewer is displaying an image.
@@ -630,6 +670,7 @@ class Viewer(QtWidgets.QFrame):
     def set_show_filenames(self, enabled, update=False):
         """Enable/disable displaying the selected filename"""
         self.filename.setVisible(enabled)
+        self.diffstat.setVisible(enabled)
         if update:
             with qtutils.BlockSignals(self.options.show_filenames):
                 self.options.show_filenames.setChecked(enabled)
@@ -796,7 +837,7 @@ class Options(QtWidgets.QWidget):
             self, N_('Enable word wrapping'), self.set_word_wrapping, True
         )
 
-        self.options = qtutils.create_action_button(
+        self.options = qtutils.create_toolbutton(
             tooltip=N_('Diff Options'), icon=icons.configure()
         )
 
@@ -903,7 +944,6 @@ class Options(QtWidgets.QWidget):
         self.function_context.setVisible(False)
 
 
-# pylint: disable=too-many-ancestors
 class DiffEditor(DiffTextEdit):
     up = Signal()
     down = Signal()
@@ -1404,6 +1444,113 @@ def _write_patch_to_file(diff_editor, patch, filename, append=False):
     Interaction.log('Patch written to "%s"' % filename)
 
 
+class ObjectIdLabel(PlainTextLabel):
+    """Interactive object IDs"""
+
+    def __init__(self, context, oid='', parent=None):
+        super().__init__(copy_on_click=True, parent=parent)
+        self.context = context
+        self.oid = oid
+        self.setToolTip(N_('Click to Copy'))
+        self._copy_short_action = qtutils.add_action_with_icon(
+            self,
+            icons.copy(),
+            N_('Copy Commit (Short)'),
+            self._copy_short,
+            hotkeys.COPY,
+        )
+        self._copy_long_action = qtutils.add_action_with_icon(
+            self,
+            icons.copy(),
+            N_('Copy Commit'),
+            self._copy_long,
+            hotkeys.COPY_COMMIT_ID,
+        )
+        self.timer = label_selection_timer(self)
+
+    def set_oid(self, oid):
+        """Record the object ID and update the display"""
+        self.oid = oid
+        self.set_text(oid)
+
+    def _copy_short(self, clicked=False):
+        """Copy the abbreviated commit ID"""
+        abbrev = prefs.abbrev(self.context)
+        qtutils.set_clipboard(self.oid[:abbrev])
+        self.start_selection_timer()
+
+    def _copy_long(self):
+        """Copy the full commit ID"""
+        qtutils.set_clipboard(self.oid)
+        self.start_selection_timer()
+
+    def copy_all_callback(self):
+        self._copy_short(clicked=True)
+
+    def context_menu_actions(self, menu):
+        """Display a custom context menu"""
+        self.copy_selection_action.setEnabled(bool(self.selectedText()))
+        menu.addAction(self._copy_long_action)
+        menu.addAction(self._copy_short_action)
+        menu.addAction(self.copy_selection_action)
+        menu.addSeparator()
+        menu.addAction(self.select_all_action)
+
+
+class AuthorLabel(PlainTextLabel):
+    """Custom actions for the author label"""
+
+    def __init__(self, parent=None):
+        super().__init__(parent=parent)
+        self._author = ''
+        self._email = ''
+        self._copy_name_action = qtutils.add_action_with_icon(
+            self,
+            icons.copy(),
+            N_('Copy Name'),
+            self._copy_name,
+        )
+        self._copy_email_action = qtutils.add_action_with_icon(
+            self,
+            icons.copy(),
+            N_('Copy Email'),
+            self._copy_email,
+        )
+        self._send_email_action = qtutils.add_action(
+            self,
+            N_('Send Email'),
+            self._send_email,
+        )
+
+    def set_author(self, author, email):
+        """Set the author and email for the label"""
+        self._author = author
+        self._email = email
+
+    def _copy_email(self):
+        """Copy the author's email address"""
+        qtutils.set_clipboard(self._email)
+        self.start_selection_timer()
+
+    def _copy_name(self):
+        """Copy the author's name"""
+        qtutils.set_clipboard(self._author)
+        self.start_selection_timer()
+
+    def _send_email(self):
+        url = QtCore.QUrl(f'mailto:{self._author} <{self._email}>')
+        QtGui.QDesktopServices.openUrl(url)
+        self.start_selection_timer()
+
+    def context_menu_actions(self, menu):
+        menu.addAction(self._send_email_action)
+        menu.addSeparator()
+        menu.addAction(self._copy_name_action)
+        menu.addAction(self._copy_email_action)
+        menu.addSeparator()
+        super().context_menu_actions(menu)
+
+
 class DiffWidget(QtWidgets.QWidget):
     """Display commit metadata and text diffs"""
 
@@ -1424,23 +1571,14 @@ class DiffWidget(QtWidgets.QWidget):
 
         self.gravatar_label = gravatar.GravatarLabel(self.context, parent=self)
 
-        self.oid_label = PlainTextLabel(parent=self)
-        self.oid_label.setAlignment(Qt.AlignBottom)
-        self.oid_label.elide()
-
-        self.author_label = RichTextLabel(parent=self)
-        self.author_label.setFont(author_font)
-        self.author_label.setAlignment(Qt.AlignTop)
-        self.author_label.elide()
-
-        self.date_label = PlainTextLabel(parent=self)
-        self.date_label.setAlignment(Qt.AlignTop)
-        self.date_label.elide()
-
-        self.summary_label = PlainTextLabel(parent=self)
-        self.summary_label.setFont(summary_font)
-        self.summary_label.setAlignment(Qt.AlignTop)
-        self.summary_label.elide()
+        self.oid_label = ObjectIdLabel(context, parent=self).align_bottom().elide()
+        self.author_label = (
+            AuthorLabel(parent=self).set_font(author_font).align_top().elide()
+        )
+        self.date_label = PlainTextLabel(parent=self).align_top().elide()
+        self.summary_label = (
+            PlainTextLabel(parent=self).set_font(summary_font).align_top().elide()
+        )
 
         self.diff = DiffTextEdit(context, self, is_commit=is_commit, whitespace=False)
         self.setFocusProxy(self.diff)
@@ -1522,24 +1660,19 @@ class DiffWidget(QtWidgets.QWidget):
         self.diff.set_diff(diff)
 
     def set_details(self, oid, author, email, date, summary):
-        template_args = {'author': author, 'email': email, 'summary': summary}
-        author_text = (
-            """%(author)s &lt;"""
-            """<a href="mailto:%(email)s">"""
-            """%(email)s</a>&gt;""" % template_args
-        )
-        author_template = '%(author)s <%(email)s>' % template_args
-
+        template_args = {'author': author, 'email': email}
+        author_text = '%(author)s <%(email)s>' % template_args
         self.date_label.set_text(date)
         self.date_label.setVisible(bool(date))
-        self.oid_label.set_text(oid)
-        self.author_label.set_template(author_text, author_template)
+        self.oid_label.set_oid(oid)
+        self.author_label.set_author(author, email)
+        self.author_label.set_text(author_text)
         self.summary_label.set_text(summary)
         self.gravatar_label.set_email(email)
 
     def clear(self):
         self.date_label.set_text('')
-        self.oid_label.set_text('')
+        self.oid_label.set_oid('')
         self.author_label.set_text('')
         self.summary_label.set_text('')
         self.gravatar_label.clear()
@@ -1547,14 +1680,15 @@ class DiffWidget(QtWidgets.QWidget):
 
     def files_selected(self, filenames):
         """Update the view when a filename is selected"""
-        if not filenames:
-            return
         oid_start = self.oid_start
         oid_end = self.oid_end
+        extra_args = {}
+        if filenames:
+            extra_args['filename'] = filenames[0]
         if oid_start and oid_end:
-            self.set_diff_range(oid_start.oid, oid_end.oid, filename=filenames[0])
+            self.set_diff_range(oid_start.oid, oid_end.oid, **extra_args)
         else:
-            self.set_diff_oid(self.oid, filename=filenames[0])
+            self.set_diff_oid(self.oid, **extra_args)
 
 
 class DiffPanel(QtWidgets.QWidget):
@@ -1688,7 +1822,6 @@ class ApplyPatches(standard.Dialog):
 
         self.tree = PatchTreeWidget(parent=self)
         self.tree.setHeaderHidden(True)
-        # pylint: disable=no-member
         self.tree.itemSelectionChanged.connect(self._tree_selection_changed)
 
         self.diffwidget = DiffWidget(context, self, is_commit=True)
@@ -1753,7 +1886,7 @@ class ApplyPatches(standard.Dialog):
         qtutils.connect_button(self.apply_button, self.apply_patches)
         qtutils.connect_button(self.close_button, self.close)
 
-        self.init_state(None, self.resize, 666, 420)
+        self.init_state(None, self.resize, 720, 480)
 
     def apply_patches(self):
         items = self.tree.items()
@@ -1823,7 +1956,6 @@ class ApplyPatches(standard.Dialog):
         return result
 
 
-# pylint: disable=too-many-ancestors
 class PatchTreeWidget(standard.DraggableTreeWidget):
     def add_paths(self, paths):
         patches = get_patches_from_paths(paths)
