@@ -8,7 +8,6 @@ from qtpy import QtWidgets
 from qtpy.QtCore import Qt
 from qtpy.QtCore import Signal
 
-from ..compat import uchr
 from ..compat import WIN32
 from ..i18n import N_
 from ..interaction import Interaction
@@ -40,7 +39,6 @@ from . import compare
 from . import createbranch
 from . import createtag
 from . import dag
-from . import defs
 from . import diff
 from . import finder
 from . import editremotes
@@ -144,28 +142,21 @@ class MainView(standard.MainWindow):
         self.submoduleswidget = self.submodulesdock.widget()
 
         # "Commit Message Editor" widget
-        self.position_label = QtWidgets.QLabel()
-        self.position_label.setAlignment(Qt.AlignCenter)
-        font = qtutils.default_monospace_font()
-        font.setPointSize(int(font.pointSize() * 0.8))
-        self.position_label.setFont(font)
-
-        # make the position label fixed size to avoid layout issues
-        text_width = qtutils.text_width(font, '99:999')
-        width = text_width + defs.spacing
-        self.position_label.setMinimumWidth(width)
-
         editor = commitmsg.CommitMessageEditor(context, self)
         self.commiteditor = editor
-        self.commitdock = create_dock('Commit', N_('Commit'), self, widget=editor)
+        self.commitdock = create_dock(
+            'Commit', N_('Commit'), self, widget=editor, hide_title=True, stretch=False
+        )
         titlebar = self.commitdock.titleBarWidget()
-        titlebar.add_title_widget(self.commiteditor.commit_progress_bar)
-        titlebar.add_corner_widget(self.position_label)
+        titlebar.add_title_widget(self.commiteditor.topwidget)
+        self.commitdock.setTabOrder(
+            self.commiteditor.summary, self.commiteditor.description
+        )
 
         # "Console" widget
         self.logwidget = log.LogWidget(context)
         self.logdock = create_dock(
-            'Console', N_('Console'), self, widget=self.logwidget
+            'Console', N_('Console'), self, widget=self.logwidget, hide_title=True
         )
         qtutils.hide_dock(self.logdock)
 
@@ -175,55 +166,44 @@ class MainView(standard.MainWindow):
             N_('Diff'),
             self,
             func=lambda dock: diff.Viewer(context, parent=dock),
+            hide_title=True,
         )
         self.diffviewer = self.diffdock.widget()
         self.diffviewer.set_diff_type(self.model.diff_type)
         self.diffviewer.enable_filename_tracking()
         self.diffeditor = self.diffviewer.text
         titlebar = self.diffdock.titleBarWidget()
+        titlebar.add_title_widget(self.diffviewer.options)
         titlebar.add_title_widget(self.diffviewer.filename)
-        titlebar.add_corner_widget(self.diffviewer.options)
+        titlebar.add_corner_widget(self.diffviewer.diffstat)
 
         # All Actions
-        add_action = qtutils.add_action
-        add_action_bool = qtutils.add_action_bool
-
-        self.commit_amend_action = add_action_bool(
-            self,
-            N_('Amend Last Commit'),
-            partial(cmds.do, cmds.AmendMode, context),
-            False,
-        )
-        self.commit_amend_action.setIcon(icons.edit())
-        self.commit_amend_action.setShortcuts(hotkeys.AMEND)
-        self.commit_amend_action.setShortcutContext(Qt.WidgetShortcut)
-
         # Make Cmd-M minimize the window on macOS.
         if utils.is_darwin():
-            self.minimize_action = add_action(
+            self.minimize_action = qtutils.add_action(
                 self, N_('Minimize Window'), self.showMinimized, hotkeys.MACOS_MINIMIZE
             )
-        self.unstage_all_action = add_action(
+        self.unstage_all_action = qtutils.add_action(
             self, N_('Unstage All'), cmds.run(cmds.UnstageAll, context)
         )
         self.unstage_all_action.setIcon(icons.remove())
 
-        self.undo_commit_action = add_action(
+        self.undo_commit_action = qtutils.add_action(
             self, N_('Undo Last Commit'), cmds.run(cmds.UndoLastCommit, context)
         )
         self.undo_commit_action.setIcon(icons.style_dialog_discard())
 
-        self.unstage_selected_action = add_action(
+        self.unstage_selected_action = qtutils.add_action(
             self, N_('Unstage'), cmds.run(cmds.UnstageSelected, context)
         )
         self.unstage_selected_action.setIcon(icons.remove())
 
-        self.show_diffstat_action = add_action(
+        self.show_diffstat_action = qtutils.add_action(
             self, N_('Diffstat'), self.statuswidget.select_header, hotkeys.DIFFSTAT
         )
         self.show_diffstat_action.setIcon(icons.diff())
 
-        self.stage_modified_action = add_action(
+        self.stage_modified_action = qtutils.add_action(
             self,
             cmds.StageModified.name(),
             cmds.run(cmds.StageModified, context),
@@ -231,7 +211,7 @@ class MainView(standard.MainWindow):
         )
         self.stage_modified_action.setIcon(icons.add())
 
-        self.stage_untracked_action = add_action(
+        self.stage_untracked_action = qtutils.add_action(
             self,
             cmds.StageUntracked.name(),
             cmds.run(cmds.StageUntracked, context),
@@ -239,7 +219,7 @@ class MainView(standard.MainWindow):
         )
         self.stage_untracked_action.setIcon(icons.add())
 
-        self.apply_patches_action = add_action(
+        self.apply_patches_action = qtutils.add_action(
             self, N_('Apply Patches...'), partial(diff.apply_patches, context)
         )
         self.apply_patches_action.setIcon(icons.diff())
@@ -268,7 +248,7 @@ class MainView(standard.MainWindow):
         )
         self.apply_patches_skip_action.setIcon(icons.discard())
 
-        self.export_patches_action = add_action(
+        self.export_patches_action = qtutils.add_action(
             self,
             N_('Export Patches...'),
             partial(guicmds.export_patches, context),
@@ -276,12 +256,12 @@ class MainView(standard.MainWindow):
         )
         self.export_patches_action.setIcon(icons.save())
 
-        self.new_repository_action = add_action(
+        self.new_repository_action = qtutils.add_action(
             self, N_('New Repository...'), partial(guicmds.open_new_repo, context)
         )
         self.new_repository_action.setIcon(icons.new())
 
-        self.new_bare_repository_action = add_action(
+        self.new_bare_repository_action = qtutils.add_action(
             self, N_('New Bare Repository...'), partial(guicmds.new_bare_repo, context)
         )
         self.new_bare_repository_action.setIcon(icons.new())
@@ -289,17 +269,17 @@ class MainView(standard.MainWindow):
         prefs_func = partial(
             prefs_widget.preferences, context, parent=self, model=prefs_model
         )
-        self.preferences_action = add_action(
+        self.preferences_action = qtutils.add_action(
             self, N_('Preferences'), prefs_func, QtGui.QKeySequence.Preferences
         )
         self.preferences_action.setIcon(icons.configure())
 
-        self.edit_remotes_action = add_action(
+        self.edit_remotes_action = qtutils.add_action(
             self, N_('Edit Remotes...'), partial(editremotes.editor, context)
         )
         self.edit_remotes_action.setIcon(icons.edit())
 
-        self.rescan_action = add_action(
+        self.rescan_action = qtutils.add_action(
             self,
             cmds.Refresh.name(),
             cmds.run(cmds.Refresh, context),
@@ -307,7 +287,7 @@ class MainView(standard.MainWindow):
         )
         self.rescan_action.setIcon(icons.sync())
 
-        self.find_files_action = add_action(
+        self.find_files_action = qtutils.add_action(
             self,
             N_('Find Files'),
             partial(finder.finder, context),
@@ -315,7 +295,7 @@ class MainView(standard.MainWindow):
         )
         self.find_files_action.setIcon(icons.search())
 
-        self.browse_recently_modified_action = add_action(
+        self.browse_recently_modified_action = qtutils.add_action(
             self,
             N_('Recently Modified Files...'),
             partial(recent.browse_recent_files, context),
@@ -323,60 +303,62 @@ class MainView(standard.MainWindow):
         )
         self.browse_recently_modified_action.setIcon(icons.directory())
 
-        self.cherry_pick_action = add_action(
+        self.cherry_pick_action = qtutils.add_action(
             self,
             N_('Cherry-Pick...'),
             partial(guicmds.cherry_pick, context),
             hotkeys.CHERRY_PICK,
         )
         self.cherry_pick_action.setIcon(icons.cherry_pick())
-        self.cherry_pick_abort_action = add_action(
+        self.cherry_pick_abort_action = qtutils.add_action(
             self, N_('Abort Cherry-Pick...'), cmds.run(cmds.AbortCherryPick, context)
         )
         self.cherry_pick_abort_action.setIcon(icons.style_dialog_discard())
 
-        self.load_commitmsg_action = add_action(
+        self.load_commitmsg_action = qtutils.add_action(
             self, N_('Load Commit Message...'), partial(guicmds.load_commitmsg, context)
         )
         self.load_commitmsg_action.setIcon(icons.file_text())
 
-        self.prepare_commitmsg_hook_action = add_action(
+        self.prepare_commitmsg_hook_action = qtutils.add_action(
             self,
             N_('Prepare Commit Message'),
             cmds.run(cmds.PrepareCommitMessageHook, context),
             hotkeys.PREPARE_COMMIT_MESSAGE,
         )
 
-        self.save_tarball_action = add_action(
+        self.save_tarball_action = qtutils.add_action(
             self, N_('Save As Tarball/Zip...'), partial(archive.save_archive, context)
         )
         self.save_tarball_action.setIcon(icons.file_zip())
 
-        self.quit_action = add_action(self, N_('Quit'), self.close, hotkeys.QUIT)
+        self.quit_action = qtutils.add_action(
+            self, N_('Quit'), self.close, hotkeys.QUIT
+        )
 
-        self.grep_action = add_action(
+        self.grep_action = qtutils.add_action(
             self, N_('Grep'), partial(grep.grep, context), hotkeys.GREP
         )
         self.grep_action.setIcon(icons.search())
 
-        self.merge_local_action = add_action(
+        self.merge_local_action = qtutils.add_action(
             self, N_('Merge...'), partial(merge.local_merge, context), hotkeys.MERGE
         )
         self.merge_local_action.setIcon(icons.merge())
 
-        self.merge_abort_action = add_action(
+        self.merge_abort_action = qtutils.add_action(
             self, N_('Abort Merge...'), cmds.run(cmds.AbortMerge, context)
         )
         self.merge_abort_action.setIcon(icons.style_dialog_discard())
 
-        self.update_submodules_action = add_action(
+        self.update_submodules_action = qtutils.add_action(
             self,
             N_('Update All Submodules...'),
             cmds.run(cmds.SubmodulesUpdate, context),
         )
         self.update_submodules_action.setIcon(icons.sync())
 
-        self.add_submodule_action = add_action(
+        self.add_submodule_action = qtutils.add_action(
             self,
             N_('Add Submodule...'),
             partial(submodules.add_submodule, context, parent=self),
@@ -410,12 +392,12 @@ class MainView(standard.MainWindow):
         )
         self.pull_action.setIcon(icons.pull())
 
-        self.open_repo_action = add_action(
+        self.open_repo_action = qtutils.add_action(
             self, N_('Open...'), partial(guicmds.open_repo, context), hotkeys.OPEN
         )
         self.open_repo_action.setIcon(icons.folder())
 
-        self.open_repo_new_action = add_action(
+        self.open_repo_new_action = qtutils.add_action(
             self,
             N_('Open in New Window...'),
             partial(guicmds.open_repo_in_new_window, context),
@@ -479,92 +461,92 @@ class MainView(standard.MainWindow):
         )
         self.restore_worktree_action.setIcon(icons.edit())
 
-        self.clone_repo_action = add_action(
+        self.clone_repo_action = qtutils.add_action(
             self, N_('Clone...'), partial(clone.clone, context)
         )
         self.clone_repo_action.setIcon(icons.repo())
 
-        self.help_docs_action = add_action(
+        self.help_docs_action = qtutils.add_action(
             self,
             N_('Documentation'),
             resources.show_html_docs,
             QtGui.QKeySequence.HelpContents,
         )
 
-        self.help_shortcuts_action = add_action(
+        self.help_shortcuts_action = qtutils.add_action(
             self, N_('Keyboard Shortcuts'), about.show_shortcuts, hotkeys.QUESTION
         )
 
-        self.visualize_current_action = add_action(
+        self.visualize_current_action = qtutils.add_action(
             self,
             N_('Visualize Current Branch...'),
             cmds.run(cmds.VisualizeCurrent, context),
         )
         self.visualize_current_action.setIcon(icons.visualize())
 
-        self.visualize_all_action = add_action(
+        self.visualize_all_action = qtutils.add_action(
             self, N_('Visualize All Branches...'), cmds.run(cmds.VisualizeAll, context)
         )
         self.visualize_all_action.setIcon(icons.visualize())
 
-        self.search_commits_action = add_action(
+        self.search_commits_action = qtutils.add_action(
             self, N_('Search...'), partial(search.search, context)
         )
         self.search_commits_action.setIcon(icons.search())
 
-        self.browse_branch_action = add_action(
+        self.browse_branch_action = qtutils.add_action(
             self,
             N_('Browse Current Branch...'),
             partial(guicmds.browse_current, context),
         )
         self.browse_branch_action.setIcon(icons.directory())
 
-        self.browse_other_branch_action = add_action(
+        self.browse_other_branch_action = qtutils.add_action(
             self, N_('Browse Other Branch...'), partial(guicmds.browse_other, context)
         )
         self.browse_other_branch_action.setIcon(icons.directory())
 
-        self.load_commitmsg_template_action = add_action(
+        self.load_commitmsg_template_action = qtutils.add_action(
             self,
             N_('Get Commit Message Template'),
             cmds.run(cmds.LoadCommitMessageFromTemplate, context),
         )
         self.load_commitmsg_template_action.setIcon(icons.style_dialog_apply())
 
-        self.help_about_action = add_action(
+        self.help_about_action = qtutils.add_action(
             self, N_('About'), partial(about.about_dialog, context)
         )
 
-        self.diff_against_commit_action = add_action(
+        self.diff_against_commit_action = qtutils.add_action(
             self,
             N_('Against Commit... (Diff Mode)'),
             partial(guicmds.diff_against_commit, context),
         )
         self.diff_against_commit_action.setIcon(icons.compare())
 
-        self.exit_diff_mode_action = add_action(
+        self.exit_diff_mode_action = qtutils.add_action(
             self, N_('Exit Diff Mode'), cmds.run(cmds.ResetMode, context)
         )
         self.exit_diff_mode_action.setIcon(icons.compare())
 
-        self.diff_expression_action = add_action(
+        self.diff_expression_action = qtutils.add_action(
             self, N_('Expression...'), partial(guicmds.diff_expression, context)
         )
         self.diff_expression_action.setIcon(icons.compare())
 
-        self.branch_compare_action = add_action(
+        self.branch_compare_action = qtutils.add_action(
             self, N_('Branches...'), partial(compare.compare_branches, context)
         )
         self.branch_compare_action.setIcon(icons.compare())
 
-        self.create_tag_action = add_action(
+        self.create_tag_action = qtutils.add_action(
             self,
             N_('Create Tag...'),
             partial(createtag.create_tag, context),
         )
         self.create_tag_action.setIcon(icons.tag())
 
-        self.create_branch_action = add_action(
+        self.create_branch_action = qtutils.add_action(
             self,
             N_('Create...'),
             partial(createbranch.create_new_branch, context),
@@ -572,24 +554,24 @@ class MainView(standard.MainWindow):
         )
         self.create_branch_action.setIcon(icons.branch())
 
-        self.delete_branch_action = add_action(
+        self.delete_branch_action = qtutils.add_action(
             self, N_('Delete...'), partial(guicmds.delete_branch, context)
         )
         self.delete_branch_action.setIcon(icons.discard())
 
-        self.delete_remote_branch_action = add_action(
+        self.delete_remote_branch_action = qtutils.add_action(
             self,
             N_('Delete Remote Branch...'),
             partial(guicmds.delete_remote_branch, context),
         )
         self.delete_remote_branch_action.setIcon(icons.discard())
 
-        self.rename_branch_action = add_action(
+        self.rename_branch_action = qtutils.add_action(
             self, N_('Rename Branch...'), partial(guicmds.rename_branch, context)
         )
         self.rename_branch_action.setIcon(icons.edit())
 
-        self.checkout_branch_action = add_action(
+        self.checkout_branch_action = qtutils.add_action(
             self,
             N_('Checkout...'),
             partial(guicmds.checkout_branch, context),
@@ -597,20 +579,20 @@ class MainView(standard.MainWindow):
         )
         self.checkout_branch_action.setIcon(icons.branch())
 
-        self.branch_review_action = add_action(
+        self.branch_review_action = qtutils.add_action(
             self, N_('Review...'), partial(guicmds.review_branch, context)
         )
         self.branch_review_action.setIcon(icons.compare())
 
-        self.browse_action = add_action(
+        self.browse_action = qtutils.add_action(
             self, N_('File Browser...'), partial(browse.worktree_browser, context)
         )
         self.browse_action.setIcon(icons.cola())
 
-        self.dag_action = add_action(self, N_('DAG...'), self.git_dag)
+        self.dag_action = qtutils.add_action(self, N_('DAG...'), self.git_dag)
         self.dag_action.setIcon(icons.cola())
 
-        self.rebase_start_action = add_action(
+        self.rebase_start_action = qtutils.add_action(
             self,
             N_('Start Interactive Rebase...'),
             cmds.run(cmds.Rebase, context),
@@ -618,12 +600,12 @@ class MainView(standard.MainWindow):
         )
         self.rebase_start_action.setIcon(icons.play())
 
-        self.rebase_edit_todo_action = add_action(
+        self.rebase_edit_todo_action = qtutils.add_action(
             self, N_('Edit...'), cmds.run(cmds.RebaseEditTodo, context)
         )
         self.rebase_edit_todo_action.setIcon(icons.edit())
 
-        self.rebase_continue_action = add_action(
+        self.rebase_continue_action = qtutils.add_action(
             self,
             N_('Continue'),
             cmds.run(cmds.RebaseContinue, context),
@@ -631,12 +613,12 @@ class MainView(standard.MainWindow):
         )
         self.rebase_continue_action.setIcon(icons.play())
 
-        self.rebase_skip_action = add_action(
+        self.rebase_skip_action = qtutils.add_action(
             self, N_('Skip Current Patch'), cmds.run(cmds.RebaseSkip, context)
         )
         self.rebase_skip_action.setIcon(icons.delete())
 
-        self.rebase_abort_action = add_action(
+        self.rebase_abort_action = qtutils.add_action(
             self, N_('Abort'), cmds.run(cmds.RebaseAbort, context)
         )
         self.rebase_abort_action.setIcon(icons.close())
@@ -665,15 +647,22 @@ class MainView(standard.MainWindow):
             self, N_('Initialize Git LFS'), cmds.run(cmds.LFSInstall, context)
         )
 
-        self.lock_layout_action = add_action_bool(
+        self.lock_layout_action = qtutils.add_action_bool(
             self, N_('Lock Layout'), self.set_lock_layout, False
         )
 
-        self.reset_layout_action = add_action(
+        self.reset_layout_action = qtutils.add_action(
             self, N_('Reset Layout'), self.reset_layout
         )
 
-        self.quick_repository_search = add_action(
+        self.save_layout_action = qtutils.add_action(
+            self, N_('Save Layout'), lambda: guicmds.save_layout(self)
+        )
+        self.load_layout_action = qtutils.add_action(
+            self, N_('Load Layout'), lambda: guicmds.load_layout(self)
+        )
+
+        self.quick_repository_search = qtutils.add_action(
             self,
             N_('Quick Open...'),
             lambda: guicmds.open_quick_repo_search(self.context, parent=self),
@@ -750,21 +739,33 @@ class MainView(standard.MainWindow):
         edit_proxy.override('selectAll', select_widgets)
 
         edit_menu = self.edit_menu = add_menu(N_('&Edit'), self.menubar)
-        undo = add_action(edit_menu, N_('Undo'), edit_proxy.undo, hotkeys.UNDO)
+        undo = qtutils.add_action(edit_menu, N_('Undo'), edit_proxy.undo, hotkeys.UNDO)
         undo.setIcon(icons.undo())
-        redo = add_action(edit_menu, N_('Redo'), edit_proxy.redo, hotkeys.REDO)
+        redo = qtutils.add_action(edit_menu, N_('Redo'), edit_proxy.redo, hotkeys.REDO)
         redo.setIcon(icons.redo())
         edit_menu.addSeparator()
-        cut = add_action(edit_menu, N_('Cut'), edit_proxy.cut, hotkeys.CUT)
+        cut = qtutils.add_action(edit_menu, N_('Cut'), edit_proxy.cut, hotkeys.CUT)
         cut.setIcon(icons.cut())
-        copy = add_action(edit_menu, N_('Copy'), edit_proxy.copy, hotkeys.COPY)
+        copy = qtutils.add_action(edit_menu, N_('Copy'), edit_proxy.copy, hotkeys.COPY)
         copy.setIcon(icons.copy())
-        paste = add_action(edit_menu, N_('Paste'), edit_proxy.paste, hotkeys.PASTE)
+        copy_commit_id = qtutils.add_action(
+            edit_menu,
+            N_('Copy Commit'),
+            lambda: guicmds.copy_commit_id_to_clipboard(context),
+            hotkeys.COPY_COMMIT_ID,
+        )
+        copy_commit_id.setIcon(icons.copy())
+        self.addAction(copy_commit_id)
+        paste = qtutils.add_action(
+            edit_menu, N_('Paste'), edit_proxy.paste, hotkeys.PASTE
+        )
         paste.setIcon(icons.paste())
-        delete = add_action(edit_menu, N_('Delete'), edit_proxy.delete, hotkeys.DELETE)
+        delete = qtutils.add_action(
+            edit_menu, N_('Delete'), edit_proxy.delete, hotkeys.DELETE
+        )
         delete.setIcon(icons.delete())
         edit_menu.addSeparator()
-        select_all = add_action(
+        select_all = qtutils.add_action(
             edit_menu, N_('Select All'), edit_proxy.selectAll, hotkeys.SELECT_ALL
         )
         select_all.setIcon(icons.select_all())
@@ -796,7 +797,7 @@ class MainView(standard.MainWindow):
         self.commit_menu = add_menu(N_('Commit@@verb'), self.menubar)
         self.commit_menu.setTitle(N_('Commit@@verb'))
         self.commit_menu.addAction(self.commiteditor.commit_action)
-        self.commit_menu.addAction(self.commit_amend_action)
+        self.commit_menu.addAction(self.commiteditor.amend_action)
         self.commit_menu.addAction(self.undo_commit_action)
         self.commit_menu.addSeparator()
         self.commit_menu.addAction(self.statuswidget.tree.process_selection_action)
@@ -905,13 +906,8 @@ class MainView(standard.MainWindow):
         )
 
         prefs_model.config_updated.connect(self._config_updated)
-
-        # Set a default value
-        self.show_cursor_position(1, 0)
-
         self.commit_menu.aboutToShow.connect(self.update_menu_actions)
         self.open_recent_menu.aboutToShow.connect(self.build_recent_menu)
-        self.commiteditor.cursor_changed.connect(self.show_cursor_position)
 
         self.diffeditor.options_changed.connect(self.statuswidget.refresh)
         self.diffeditor.up.connect(self.statuswidget.move_up)
@@ -1025,7 +1021,12 @@ class MainView(standard.MainWindow):
 
         menu.addSeparator()
         menu.addAction(self.lock_layout_action)
-        menu.addAction(self.reset_layout_action)
+
+        layout_menu = menu.addMenu(N_('Layouts'))
+        layout_menu.addAction(self.save_layout_action)
+        layout_menu.addAction(self.load_layout_action)
+        layout_menu.addAction(self.reset_layout_action)
+        guicmds.build_layout_menu(self, layout_menu)
 
         return menu
 
@@ -1048,7 +1049,7 @@ class MainView(standard.MainWindow):
                 # Omit the current worktree from the "Open Recent" menu.
                 continue
             name = entry['name']
-            text = f'{name} {uchr(0x2192)} {directory}'
+            text = f'{name} {chr(0x2192)} {directory}'
             menu.addAction(text, cmds.run(cmd, context, directory))
 
     # Accessors
@@ -1110,7 +1111,10 @@ class MainView(standard.MainWindow):
         is_applying_patch = self.model.is_applying_patch
         is_cherry_picking = self.model.is_rebasing
 
-        curdir = core.getcwd()
+        try:
+            curdir = core.getcwd()
+        except FileNotFoundError:
+            return
         msg = N_('Repository: %s') % curdir
         msg += '\n'
         msg += N_('Branch: %s') % curbranch
@@ -1142,12 +1146,6 @@ class MainView(standard.MainWindow):
             )
 
         self.refresh_window_title()
-
-        if self.mode == self.model.mode_amend:
-            self.commit_amend_action.setChecked(True)
-        else:
-            self.commit_amend_action.setChecked(False)
-
         self.commitdock.setToolTip(msg)
 
         self.actionswidget.set_mode(self.mode)
@@ -1169,8 +1167,8 @@ class MainView(standard.MainWindow):
         is_diff_mode = self.model.is_diff_mode()
         is_amend_mode = self.mode == self.model.mode_amend
 
-        prefix = uchr(0xAB)
-        suffix = uchr(0xBB)
+        prefix = chr(0xAB)
+        suffix = chr(0xBB)
 
         if is_amend_mode:
             alerts.append(N_('Amending'))
@@ -1224,17 +1222,19 @@ class MainView(standard.MainWindow):
         self.prepare_commitmsg_hook_action.setEnabled(enabled)
 
     def export_state(self):
+        """Save persistent UI state on shutdown"""
         state = standard.MainWindow.export_state(self)
         show_status_filter = self.statuswidget.filter_widget.isVisible()
         state['show_status_filter'] = show_status_filter
         state['toolbars'] = self.toolbar_state.export_state()
         state['ref_sort'] = self.model.ref_sort
         self.diffviewer.export_state(state)
+        self.commiteditor.export_state(state)
 
         return state
 
     def apply_state(self, state):
-        """Imports data for save/restore"""
+        """Apply persistent UI state on startup"""
         base_ok = standard.MainWindow.apply_state(self, state)
         lock_layout = state.get('lock_layout', False)
         self.lock_layout_action.setChecked(lock_layout)
@@ -1249,7 +1249,8 @@ class MainView(standard.MainWindow):
         self.model.set_ref_sort(sort_key)
 
         diff_ok = self.diffviewer.apply_state(state)
-        return base_ok and diff_ok
+        commitmsg_ok = self.commiteditor.apply_state(state)
+        return base_ok and diff_ok and commitmsg_ok
 
     def setup_dockwidget_view_menu(self):
         # Hotkeys for toggling the dock widgets
@@ -1318,38 +1319,6 @@ class MainView(standard.MainWindow):
     def git_dag(self):
         self.dag = dag.git_dag(self.context, existing_view=self.dag)
 
-    def show_cursor_position(self, rows, cols):
-        display_content = '%02d:%02d' % (rows, cols)
-        css = """
-            <style>
-            .good {
-            }
-            .first-warning {
-                color: black;
-                background-color: yellow;
-            }
-            .second-warning {
-                color: black;
-                background-color: #f83;
-            }
-            .error {
-                color: white;
-                background-color: red;
-            }
-            </style>
-        """
-
-        if cols > 78:
-            cls = 'error'
-        elif cols > 72:
-            cls = 'second-warning'
-        elif cols > 64:
-            cls = 'first-warning'
-        else:
-            cls = 'good'
-        div = f'<div class="{cls}">{display_content}</div>'
-        self.position_label.setText(css + div)
-
 
 class FocusProxy:
     """Proxy over child widgets and operate on the focused widget"""
